==> node-typescript_2.0.8.orig.tar.gz: TypeScript-2.0.8/tests/baselines/reference/computedPropertyNames16_ES5.js <==
//// [computedPropertyNames16_ES5.ts]
var s: string;
var n: number;
var a: any;
class C {
    get [s]() { return 0;}
    set [n](v) { }
    static get [s + s]() { return 0; }
    set [s + n](v) { }
    get [+s]() { return 0; }
    static set [""](v) { }
    get [0]() { return 0; }
    set [a](v) { }
    static get [<any>true]() { return 0; }
    set [`hello bye`](v) { }
    get [`hello ${a} bye`]() { return 0; }
}

//// [computedPropertyNames16_ES5.js]
var s;
var n;
var a;
var C = (function () {
    function C() {
    }
    Object.defineProperty(C.prototype, s, {
        get: function () { return 0; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(C.prototype, n, {
        set: function (v) { },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(C, s + s, {
        get: function () { return 0; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(C.prototype, s + n, {
        set: function (v) { },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(C.prototype, +s, {
        get: function () { return 0; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(C, "", {
        set: function (v) { },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(C.prototype, 0, {
        get: function () { return 0; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(C.prototype, a, {
        set: function (v) { },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(C, true, {
        get: function () { return 0; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(C.prototype, "hello bye", {
        set: function (v) { },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(C.prototype, "hello " + a + " bye", {
        get: function () { return 0; },
        enumerable: true,
        configurable: true
    });
    return C;
}());

==> node-typescript_4.0.3.orig.tar.gz: TypeScript-4.0.3/tests/baselines/reference/computedPropertyNames16_ES5.js <==
//// [computedPropertyNames16_ES5.ts]
var s: string;
var n: number;
var a: any;
class C {
    get [s]() { return 0;}
    set [n](v) { }
    static get [s + s]() { return 0; }
    set [s + n](v) { }
    get [+s]() { return 0; }
    static set [""](v) { }
    get [0]() { return 0; }
    set [a](v) { }
    static get [<any>true]() { return 0; }
    set [`hello bye`](v) { }
    get [`hello ${a} bye`]() { return 0; }
}

//// [computedPropertyNames16_ES5.js]
var s;
var n;
var a;
var C = /** @class */ (function () {
    function C() {
    }
    Object.defineProperty(C.prototype, s, {
        get: function () { return 0; },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(C.prototype, n, {
        set: function (v) { },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(C, s + s, {
        get: function () { return 0; },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(C.prototype, s + n, {
        set: function (v) { },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(C.prototype, +s, {
        get: function () { return 0; },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(C, "", {
        set: function (v) { },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(C.prototype, 0, {
        get: function () { return 0; },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(C.prototype, a, {
        set: function (v) { },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(C, true, {
        get: function () { return 0; },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(C.prototype, "hello bye", {
        set: function (v) { },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(C.prototype, "hello " + a + " bye", {
        get: function () { return 0; },
        enumerable: false,
        configurable: true
    });
    return C;
}());
